// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot;

import edu.wpi.first.math.MathUtil;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.Commands;
import edu.wpi.first.wpilibj2.command.button.CommandXboxController;
import frc.robot.constants.OIConstants;
import frc.robot.subsystems.Drivetrain;

public class RobotContainer {
  private Drivetrain drivetrain;

  private CommandXboxController primary;
  private CommandXboxController secondary;

  public RobotContainer() {
    drivetrain = new Drivetrain();

    primary = new CommandXboxController(OIConstants.kPrimaryXboxUSB);
    secondary = new CommandXboxController(OIConstants.kSecondaryXboxUSB);

    configureBindings();
  }

  private void configureBindings() {
    drivetrain.setDefaultCommand(drivetrain.teleopCommand(
      primary::getLeftX, 
      primary::getLeftY, 
      primary::getRightX, 
      OIConstants.kTeleopDriveDeadband
    ));

    primary.povCenter().onFalse(
      drivetrain.driveCardinal(
        primary::getLeftX,
        primary::getLeftY,
        primary.getHID()::getPOV,
        OIConstants.kTeleopDriveDeadband).until(
          () -> MathUtil.applyDeadband(primary.getRightX(), OIConstants.kTeleopDriveDeadband) != 0
        )
    );

    // This was originally a run while held, not sure that's really necessary
    primary.y().onTrue(drivetrain.zeroHeadingCommand());

    // This was originally a run while held, not sure that's really necessary
    primary.rightBumper().onTrue(drivetrain.setXCommand());
  }

  public Command getAutonomousCommand() {
    return Commands.print("No autonomous command configured");
  }
}
